"""
PopGen_hwe_test

Test Hardy-Weinberg equilibrium for a biallelic locus given observed genotype counts (AA, Aa, aa)...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def PopGen_hwe_test(
    operation: str,
    obs_AA: int,
    obs_Aa: int,
    obs_aa: int,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Test Hardy-Weinberg equilibrium for a biallelic locus given observed genotype counts (AA, Aa, aa)...

    Parameters
    ----------
    operation : str
        Operation type
    obs_AA : int
        Observed count of homozygous dominant (AA) genotypes
    obs_Aa : int
        Observed count of heterozygous (Aa) genotypes
    obs_aa : int
        Observed count of homozygous recessive (aa) genotypes
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v
        for k, v in {
            "operation": operation,
            "obs_AA": obs_AA,
            "obs_Aa": obs_Aa,
            "obs_aa": obs_aa,
        }.items()
        if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "PopGen_hwe_test",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["PopGen_hwe_test"]
